Index: talk/app/webrtc/statscollector.h |
diff --git a/talk/app/webrtc/statscollector.h b/talk/app/webrtc/statscollector.h |
index 714f15a4012e42bc7e3c2d55dc2c2935176a2ba1..add26c6465eee0634237d8a90caf39d175f0c52f 100644 |
--- a/talk/app/webrtc/statscollector.h |
+++ b/talk/app/webrtc/statscollector.h |
@@ -43,8 +43,6 @@ |
namespace webrtc { |
-class PeerConnection; |
- |
// Conversion function to convert candidate type string to the corresponding one |
// from enum RTCStatsIceCandidateType. |
const char* IceCandidateTypeToStatsType(const std::string& candidate_type); |
@@ -59,9 +57,9 @@ |
class StatsCollector { |
public: |
// The caller is responsible for ensuring that the pc outlives the |
// StatsCollector instance. |
- explicit StatsCollector(PeerConnection* pc); |
+ explicit StatsCollector(WebRtcSession* session); |
virtual ~StatsCollector(); |
// Adds a MediaStream with tracks that can be used as a |selector| in a call |
@@ -153,8 +151,8 @@ |
// A collection for all of our stats reports. |
StatsCollection reports_; |
TrackIdMap track_ids_; |
- // Raw pointer to the peer connection the statistics are gathered from. |
- PeerConnection* const pc_; |
+ // Raw pointer to the session the statistics are gathered from. |
+ WebRtcSession* const session_; |
double stats_gathering_started_; |
cricket::ProxyTransportMap proxy_to_transport_; |
@@ -59,9 +57,9 @@ |
class StatsCollector { |
public: |
- // The caller is responsible for ensuring that the pc outlives the |
+ // The caller is responsible for ensuring that the session outlives the |
// StatsCollector instance. |